.. skretrieval documentation master file, created by
   sphinx-quickstart on Tue Jan 15 12:30:27 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

   ##########
   Parts
   ##########

   ***************
   Chapters
   ***************

   Sections/Class headers
   ======================

   subsections  Class methods
   ---------------------------

   subsubsections
   ^^^^^^^^^^^^^^

   paragraphs
   ~~~~~~~~~~

#######################################
Welcome to skretrieval's documentation!
#######################################

`skretrieval` is a package which provides multiple pieces of functionality

  - Methods for inverse problems such as the Rodgers framework
  - Tools for creating instrument models, e.g., implementations of generic instrument concepts such as a spectrograph
  - A generic framework for simulating measurements from arbitrary instruments and performing retrievals on
    both simulated and real data

.. toctree::
   :maxdepth: 2

   retrieval
   forwardmodel
   platforms/platforms_intro
   tomography/introduction
   api/modules

*******************
Indices and tables
*******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
